==> haskell-text-icu-0.7.0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-icu.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-6fsOEPVbikhJ6ijUdaDY71
key: text-icu-0.7.0.1-6fsOEPVbikhJ6ijUdaDY71
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
abi: 0165e232aa39c04128910917763f16ad
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-icu-0.7.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-6fsOEPVbikhJ6ijUdaDY71
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-icu-0.7.0.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-text-icu.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-icu
version: 0.7.0.1
id: text-icu-0.7.0.1-GtbFFRs9sVugfs7GP5C1y
key: text-icu-0.7.0.1-GtbFFRs9sVugfs7GP5C1y
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/text-icu
synopsis: Bindings to the ICU library
description:
    Haskell bindings to the International Components for Unicode (ICU)
    libraries.  These libraries provide robust and full-featured Unicode
    services on a wide variety of platforms.
    .
    Features include:
    .
    * Both pure and impure bindings, to allow for fine control over efficiency
    and ease of use.
    .
    * Breaking of strings on character, word, sentence, and line boundaries.
    .
    * Access to the Unicode Character Database (UCD) of character metadata.
    .
    * String collation functions, for locales where the conventions for
    lexicographic ordering differ from the simple numeric ordering of
    character codes.
    .
    * Character set conversion functions, allowing conversion between
    Unicode and over 220 character encodings.
    .
    * Unicode normalization.  (When implementations keep strings in a
    normalized form, they can be assured that equivalent strings have a
    unique binary representation.)
    .
    * Regular expression search and replace.
category: Data, Text
exposed: True
exposed-modules:
    Data.Text.ICU Data.Text.ICU.Break Data.Text.ICU.Char
    Data.Text.ICU.Collate Data.Text.ICU.Convert Data.Text.ICU.Error
    Data.Text.ICU.Normalize Data.Text.ICU.Regex Data.Text.ICU.Types
hidden-modules: Data.Text.ICU.Break.Pure Data.Text.ICU.Break.Types
                Data.Text.ICU.Collate.Internal Data.Text.ICU.Collate.Pure
                Data.Text.ICU.Convert.Internal Data.Text.ICU.Error.Internal
                Data.Text.ICU.Internal Data.Text.ICU.Iterator
                Data.Text.ICU.Normalize.Internal Data.Text.ICU.Regex.Internal
                Data.Text.ICU.Regex.Pure Data.Text.ICU.Text
abi: baa6d142e2c9b756fd6e69565f6822ee
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-icu-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-icu-0.7.0.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/text-icu-0.7.0.1
hs-libraries: HStext-icu-0.7.0.1-GtbFFRs9sVugfs7GP5C1y
extra-libraries:
    icuuc icui18n icudata
depends:
    base-4.9.0.0 bytestring-0.10.8.1 deepseq-1.4.2.0
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-text-icu/html/text-icu.haddock
haddock-html: /usr/share/doc/haskell-text-icu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
